Select Widget
-------------

The select widget allows you to select one or more values from a set of given
options.

.. toctree::
   :maxdepth: 1

   Overview <select>
   Missing Terms <select-missing-terms>
   Using sources <select-source>
